Function arrow_udf::ffi::record_batch_iterator_next
source · #[no_mangle]
pub unsafe extern "C" fn record_batch_iterator_next(
iter: *mut RecordBatchIter,
out: *mut CSlice
)Expand description
Get the next record batch from the iterator.
The output record batch is written to the buffer pointed to by out.
The caller is responsible for deallocating the output buffer.
Safety
iter and out must be valid pointers.