pub unsafe fn table_wrapper(
function: TableFunction,
ptr: *const u8,
len: usize,
out_slice: *mut CSlice,
) -> i32Expand description
A wrapper for calling table functions from C.
The input record batch is read from the IPC buffer pointed to by ptr and len.
The output iterator is written to out_slice.
The return value is 0 on success, -1 on error. If successful, the record batch is written to the buffer. If failed, the error message is written to the buffer.
Safety
ptr, len, out_slice must point to a valid buffer.